import { Card, Tabs, Input, Typography, Space, Form, Button } from 'antd';

import React from 'react';
import { useState } from 'react';
import { postData, getData } from '@/services/demo';
import { ReloadOutlined, SearchOutlined } from '@ant-design/icons';

const { Text } = Typography;
const { Search } = Input;

const DemoPage: React.FC = () => {
  const [currentKey, setCurrentKey] = useState('1');
  const [tabText1, setTabText1] = useState('Tab1');
  const [tabText2, setTabText2] = useState('Tab2');
  const [tabText3, setTabText3] = useState('Tab3');
  const [form] = Form.useForm();

  const handleOnChange = (key: string) => {
    console.log('handleOnChange: ' + key);
    setCurrentKey(key);
  };

  async function onSearch(text: string) {
    console.log('Current Key: ', currentKey, ', On Search Text: ', text);

    switch (currentKey) {
      case '1': {
        const result = await postData(text);
        const res = result.data.text;
        setTabText1(res);
        break;
      }
      case '2': {
        const result = await getData(text);
        const res = result.data.text;
        setTabText2(res);
        break;
      }
      case '3': {
        const result = await postData(text);
        const res = result.data.text;
        setTabText3(res);
        break;
      }
      default: {
        console.log('On Search: Error Key');
        break;
      }
    }
  }
  return (
    <div className="site-card-border-less-wrapper">
      <Card title="demo">
        <Form form={form} layout="inline">
          <Form.Item name="first" label="第一个">
            <Input placeholder="请输入..." />
          </Form.Item>
          <Form.Item name="first" label="第二个">
            <Input placeholder="请输入..." />
          </Form.Item>
          <Form.Item style={{ marginBottom: '10px' }}>
            <Space>
              <Button type="primary" htmlType="submit">
                <SearchOutlined />
                查询
              </Button>
              <Button htmlType="button">
                <ReloadOutlined />
                重置
              </Button>
            </Space>
          </Form.Item>
        </Form>
        <Tabs defaultActiveKey="1" activeKey={currentKey} onChange={handleOnChange}>
          <Tabs.TabPane tab="Demo_Tab_1" key="1" />
          <Tabs.TabPane tab="Demo_Tab_2" key="2" />
          <Tabs.TabPane tab="Demo_Tab_3" key="3" />
        </Tabs>
        {currentKey === '1' && (
          <Space direction="vertical">
            <Search placeholder="input search text1" onSearch={onSearch} enterButton />
            <Text> {tabText1} </Text>
          </Space>
        )}
        {currentKey === '2' && (
          <Space direction="vertical">
            <Search placeholder="input search text2" onSearch={onSearch} enterButton />
            <Text> {tabText2} </Text>
          </Space>
        )}
        {currentKey === '3' && (
          <Space direction="vertical">
            <Search placeholder="input search text3" onSearch={onSearch} enterButton />
            <Text> {tabText3} </Text>
          </Space>
        )}
      </Card>
    </div>
  );
};

export default DemoPage;
